@@ -4,11 +4,12 @@ import os
 import subprocess
 from functools import wraps
 from time import time
-
+import sys
 import requests
 from RainbowMonitoringSDK.probes.Metric import SimpleMetric, Metric
 DOCKER_ID_LENGTH = 64
-
+min_inf = -1*sys.float_info.max
+max_inf = sys.float_info.max
 def get_entity_id():
     res = subprocess.Popen("head -1 /proc/self/cgroup|cut -d/ -f3", shell=True, stdout=subprocess.PIPE)
     encoded_first_line = res.stdout.readlines()[0].decode().replace("\n","")
@@ -32,10 +33,10 @@ class RainbowUtils:
 
     @classmethod
     def store(cls, value, name, units, desc,
-              minVal=float('-inf'), maxVal=float('inf'), higherIsBetter=True, in_files=False):
+              minVal=min_inf, maxVal=max_inf, higherIsBetter=True, in_files=False):
         simple_metric = SimpleMetric(name, units, desc, minVal, maxVal, higherIsBetter=higherIsBetter)
         simple_metric.set_val(value)
-        cls.__store(simple_metric, in_files=False)
+        cls.__store(simple_metric, in_files=in_files)
 
     @classmethod
     def __store(cls, metric: Metric, in_files=False):
@@ -80,7 +81,7 @@ class RainbowUtils:
         return wrap
 
     @classmethod
-    def export(cls, name, units, desc, minVal=float('-inf'), maxVal=float('inf'), higherIsBetter=True):
+    def export(cls, name, units, desc, minVal=min_inf, maxVal=max_inf, higherIsBetter=True):
         def _export(f):
             simple_metric = SimpleMetric(name, units, desc, minVal=minVal, maxVal=maxVal, higherIsBetter=higherIsBetter)
             if not callable(f):
